searchData={"items":[{"type":"module","title":"IgniterJs.Helpers","doc":"A module that contains helper functions for IgniterJs. For example it helps to normalize the\noutput of the NIFs, read and validate the file, and call the NIF function with the\ngiven file path or content.","ref":"IgniterJs.Helpers.html"},{"type":"function","title":"IgniterJs.Helpers.call_nif_fn/4","doc":"Call the NIF function with the given file path or content and return the result.\nIt helps to change the function name as atom based on its caller function.\n\n```elixir\ncall_nif_fn(\"/path/to/file.js\", __ENV__.function, fn content -> content end, :path)\ncall_nif_fn(\"file content\", __ENV__.function, fn content -> content end)\ncall_nif_fn(\"file content\", __ENV__.function, fn content -> content end, :content)\n```","ref":"IgniterJs.Helpers.html#call_nif_fn/4"},{"type":"macro","title":"IgniterJs.Helpers.normalize_output/2","doc":"Normalize the output of the NIFs. It is a macro and returns a tuple with the first\nelement as the output, the second element as the caller function name, and the\nthird element as the status.\n\n```elixir\nrequire IgniterJs.Helpers\nnormalize_output({:ok, :fun_atom, result}, __ENV__.function)\nnormalize_output({:error, :fun_atom, result}, __ENV__.function)\n```","ref":"IgniterJs.Helpers.html#normalize_output/2"},{"type":"function","title":"IgniterJs.Helpers.read_and_validate_file/1","doc":"Read and validate the file. It returns the file content if the file exists and the\nextension is `.js` or `.ts`, otherwise, it returns an error tuple.\n\n```elixir\nread_and_validate_file(\"/path/to/file.js\")\n```","ref":"IgniterJs.Helpers.html#read_and_validate_file/1"},{"type":"module","title":"IgniterJs.Parsers.Javascript.Parser","doc":"Codemods for JavaScript files.","ref":"IgniterJs.Parsers.Javascript.Parser.html"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.exist_live_socket/2","doc":"Check if a LiveSocket var exists in the given file or content and returns tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket(js_content)\nParser.exist_live_socket(js_content, :content)\nParser.exist_live_socket(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#exist_live_socket/2"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.exist_live_socket?/2","doc":"Check if a LiveSocket var exists in the given file or content and returns boolean.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket?(js_content)\nParser.exist_live_socket?(js_content, :content)\nParser.exist_live_socket?(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#exist_live_socket?/2"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.exist_var/3","doc":"Check if an specific var exists in the given file or content and returns tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket(js_content, var_name)\nParser.exist_live_socket(js_content, var_name, :content)\nParser.exist_live_socket(\"/path/to/file.js\", var_name, :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#exist_var/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.extend_hook_object/3","doc":"Extend the hook object in the given file or content. It accepts a single object\nor a list of objects.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.extend_hook_object(js_content, \"SomeObject\")\nParser.extend_hook_object(js_content, [\"SomeObject\", \"AnotherObject\"], :content)\nParser.extend_hook_object(\"/path/to/file.js\", \"SomeObject\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#extend_hook_object/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.extend_var_object_by_object_names/4","doc":"Extend a variable of object type in the given file or content by adding additional objects to it,\n  based on their names.\n\n  This function ensures that duplicate entries are not added during the process.\n\n  This function accepts:\n  - The content or path of the JavaScript file.\n  - The name of the variable to be extended.\n  - A single object name or a list of object names to be added.\n  - The type indicating whether it's content (`:content`) or a path (`:path`).\n\n  It returns a tuple with the status, function atom, and the updated content or an error message\n  if the variable could not be found or modified.","ref":"IgniterJs.Parsers.Javascript.Parser.html#extend_var_object_by_object_names/4"},{"type":"function","title":"Examples - IgniterJs.Parsers.Javascript.Parser.extend_var_object_by_object_names/4","doc":"```elixir\n  alias IgniterJs.Parsers.Javascript.Parser\n\n  objects_names = [\"OXCTestHook\", \"MishkaHooks\", \"MishkaHooks\", \"OXCTestHook\"]\n\n  Parser.extend_var_object_by_object_names(js_content, \"Components\", \"TestHook\")\n  Parser.extend_var_object_by_object_names(\"/path/to/file.js\", \"Components\", objects_names, :path)\n\n  {:error, :extend_var_object_by_object_names, _output} =\n    Parser.extend_var_object_by_object_names(\"None\", \"Components\", objects_names)\n  ```","ref":"IgniterJs.Parsers.Javascript.Parser.html#extend_var_object_by_object_names/4-examples"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.insert_imports/3","doc":"Insert imports to the given file or content and returns tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.insert_imports(js_content, imports_lines)\nParser.insert_imports(js_content, imports_lines, :content)\nParser.insert_imports(\"/path/to/file.js\", imports_lines, :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#insert_imports/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.module_imported/3","doc":"Check if a module is imported in the given file or content or contents and return tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.module_imported(js_content, \"module\")\nParser.module_imported(js_content, \"module\", :content)\nParser.module_imported(\"/path/to/file.js\", \"module\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#module_imported/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.module_imported?/3","doc":"Check if a module is imported in the given file or content or content and returns boolean.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.module_imported?(js_content, \"module\")\nParser.module_imported?(js_content, \"module\", :content)\nParser.module_imported?(\"/path/to/file.js\", \"module\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#module_imported?/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.remove_imports/3","doc":"Remove imports from the given file or content. it accepts a single module or a list of modules.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.remove_imports(js_content, \"SomeModule\")\nParser.remove_imports(\"/path/to/file.js\", \"SomeModule\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#remove_imports/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.remove_objects_from_hooks/3","doc":"Remove objects from the hooks in the given file or content. It accepts a single o\nbject or a list of objects.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.remove_objects_from_hooks(js_content, \"SomeObject\")\nParser.remove_objects_from_hooks(js_content, [\"SomeObject\", \"AnotherObject\"], :content)\nParser.remove_objects_from_hooks(\"/path/to/file.js\", \"SomeObject\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#remove_objects_from_hooks/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.statistics/2","doc":"Retrieve statistical information about the JavaScript source code, such as the number of\nfunctions, classes, debugger statements, imports, try-catch blocks, and throw statements.\n\nThis function accepts either the content of the JavaScript file or the path to the file,\nand returns a tuple with the status, function atom, and the extracted data as a map.","ref":"IgniterJs.Parsers.Javascript.Parser.html#statistics/2"},{"type":"function","title":"Examples - IgniterJs.Parsers.Javascript.Parser.statistics/2","doc":"```elixir\nalias IgniterJs.Parsers.Javascript.Parser\n\n# Analyze a JavaScript source file by providing its content\nParser.statistics(js_content)\n\n# Analyze a JavaScript source file by providing its file path\nParser.statistics(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#statistics/2-examples"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.var_exists?/2","doc":"Check if a specific var exists in the given file or content and returns boolean.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket?(js_content)\nParser.exist_live_socket?(js_content, :content)\nParser.exist_live_socket?(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#var_exists?/2"},{"type":"extras","title":"Home","doc":"[![CI](https://github.com/ash-project/igniter_js/actions/workflows/elixir.yml/badge.svg)](https://github.com/ash-project/igniter_js/actions/workflows/elixir.yml)\n[![Hex version badge](https://img.shields.io/hexpm/v/igniter_js.svg)](https://hex.pm/packages/igniter_js)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/igniter_js)\n\n# IgniterJs\n\nIgniterJs is javascript patching functionality for [Igniter](https://hexdocs.pm/igniter)","ref":"readme.html"},{"type":"extras","title":"Installation - Home","doc":"IgniterJs can be added to an existing elixir project by adding it to your dependencies:\n\n```elixir\n{:igniter_js, \"~> 0.4.4\", only: [:dev, :test]}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Status - Home","doc":"We are still working on getting this ready for an initial release.\n\nThe initial codemods will be limited to specific transformations. This is not intended to\nbe a toolkit (yet) for writing any arbitrary transformation like `Igniter` is for `Elixir`.\nWe will likely provide a way to do this by the user providing rust code and using our tools\nto hook it up to igniter.","ref":"readme.html#status"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.4.4](https://github.com/ash-project/igniter_js/compare/v0.4.3...v0.4.4) (2025-02-16)","ref":"changelog.html"},{"type":"extras","title":"Features: - Change Log","doc":"* improve import deduplication by supporting ImportDefaultSpecifier and ImportNamespaceSpecifier (#16)\n\n## [v0.4.3](https://github.com/ash-project/igniter_js/compare/v0.4.2...v0.4.3) (2025-01-18)","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* rebuild NIF without lto\n\n## [v0.4.2](https://github.com/ash-project/igniter_js/compare/v0.4.1...v0.4.2) (2025-01-17)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* rebuild NIF and downgrade rustler\n\n## [v0.4.1](https://github.com/ash-project/igniter_js/compare/v0.4.0...v0.4.1) (2025-01-17)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* rebuild NIF\n\n## [v0.4.0](https://github.com/ash-project/igniter_js/compare/v0.3.0...v0.4.0) (2025-01-17)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features: - Change Log","doc":"* migrate project from OXC to SWC, add generic helper functions, and update dependencies (#10)\n\n## [v0.3.0](https://github.com/ash-project/igniter_js/compare/v0.2.0...v0.3.0) (2025-01-08)","ref":"changelog.html#features"},{"type":"extras","title":"Features: - Change Log","doc":"* add function to extend limited objects and prevent duplicate object names during extending hooks (#9)\n\n## [v0.2.0](https://github.com/ash-project/igniter_js/compare/v0.1.2...v0.2.0) (2025-01-05)","ref":"changelog.html#features"},{"type":"extras","title":"Features: - Change Log","doc":"* parser: add function to display AST statistics and fix `Clippy` warnings (#7)\n\n## [v0.1.2](https://github.com/ash-project/igniter_js/compare/v0.1.1...v0.1.2) (2024-12-29)","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - Change Log","doc":"- Properly include all checksums\n\n\n\n## [v0.1.1](https://github.com/ash-project/igniter_js/compare/v0.1.0...v0.1.1) (2024-12-29)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* Support RustlerPrecompiled release (#3)\n\n## [v0.1.0](https://github.com/ash-project/igniter_js/compare/v0.1.0...v0.1.0) (2024-12-24)","ref":"changelog.html#improvements"},{"type":"extras","title":"Features: - Change Log","doc":"* OXC wrapper NIF & initial features","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}